@@ -77,6 +77,7 @@
 #include <QTimer>
 #include <QToolBar>
 #include <QWindow>
+#include <kwidgetsaddons_version.h>
 
 KOWindowList *ActionManager::mWindowList = nullptr;
 
@@ -924,7 +925,7 @@ void ActionManager::file_open(const QUrl &url)
     KOrg::MainWindow *korg = ActionManager::findInstance(url);
     if ((nullptr != korg) && (korg != mMainWindow)) {
 #if KDEPIM_HAVE_X11
-        KWindowSystem::activateWindow(korg->topLevelWidget()->winId());
+        KWindowSystem::activateWindow(korg->topLevelWidget()->windowHandle());
 #endif
         return;
     }
@@ -1032,7 +1033,7 @@ bool ActionManager::saveAsURL(const QUrl &url)
         mTempFile = tempFile;
         setTitle();
     } else {
-        KMessageBox::sorry(dialogParent(), i18n("Unable to save calendar to the file %1.", mFile), i18n("Error"));
+        KMessageBox::error(dialogParent(), i18n("Unable to save calendar to the file %1.", mFile), i18n("Error"));
         qCDebug(KORGANIZER_LOG) << "failed";
         mURL = URLOrig;
         mFile = fileOrig;
@@ -1075,7 +1076,7 @@ void ActionManager::configureDateTime()
     proc << QStringLiteral("kcmshell5") << QStringLiteral("formats") << QStringLiteral("translations") << QStringLiteral("clock");
 
     if (!proc.startDetached()) {
-        KMessageBox::sorry(dialogParent(), i18n("Could not start control module for date and time format."));
+        KMessageBox::error(dialogParent(), i18n("Could not start control module for date and time format."));
     }
 }
 
@@ -1596,7 +1597,12 @@ void ActionManager::updateUndoRedoActions()
 
     if (history->undoAvailable()) {
         mUndoAction->setEnabled(true);
-        mUndoAction->setText(i18n("Undo: %1", history->nextUndoDescription()));
+        QString nextUndoDescription = history->nextUndoDescription();
+        if (nextUndoDescription.length() > 30) {
+            nextUndoDescription.truncate(30);
+            nextUndoDescription += QStringLiteral("...");
+        }
+        mUndoAction->setText(i18n("Undo: %1", nextUndoDescription));
     } else {
         mUndoAction->setEnabled(false);
         mUndoAction->setText(i18n("Undo"));
@@ -1604,7 +1610,12 @@ void ActionManager::updateUndoRedoActions()
 
     if (history->redoAvailable()) {
         mRedoAction->setEnabled(true);
-        mRedoAction->setText(i18n("Redo: %1", history->nextRedoDescription()));
+        QString nextRedoDescription = history->nextRedoDescription();
+        if (nextRedoDescription.length() > 30) {
+            nextRedoDescription.truncate(30);
+            nextRedoDescription += QStringLiteral("...");
+        }
+        mRedoAction->setText(i18n("Redo: %1", nextRedoDescription));
     } else {
         mRedoAction->setEnabled(false);
         mRedoAction->setText(i18n("Redo"));
@@ -1632,17 +1643,29 @@ void ActionManager::importCalendar(const QUrl &url)
                                        "the destination calendar.</p>"
                                        "<p>If you select add, then a new calendar will be created for you automatically.</p>");
 
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+    const int answer = KMessageBox::questionTwoActionsCancel(dialogParent(),
+#else
     const int answer = KMessageBox::questionYesNoCancel(dialogParent(),
-                                                        questionText,
-                                                        i18nc("@title:window", "Import Calendar"),
-                                                        KGuiItem(i18n("Merge into existing calendar")),
-                                                        KGuiItem(i18n("Add as new calendar")));
+#endif
+                                                             questionText,
+                                                             i18nc("@title:window", "Import Calendar"),
+                                                             KGuiItem(i18n("Merge into existing calendar")),
+                                                             KGuiItem(i18n("Add as new calendar")));
 
     switch (answer) {
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+    case KMessageBox::ButtonCode::PrimaryAction: // merge
+#else
     case KMessageBox::Yes: // merge
+#endif
         importURL(url, true);
         break;
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+    case KMessageBox::ButtonCode::SecondaryAction: // import
+#else
     case KMessageBox::No: // import
+#endif
         importURL(url, false);
         break;
     default:
