@@ -8,7 +8,6 @@
 
 #include "kcmapptsummary.h"
 
-#include <KAboutData>
 #include <KAcceleratorManager>
 #include <KConfig>
 #include <KConfigGroup>
@@ -145,19 +144,4 @@ void KCMApptSummary::defaults()
     Q_EMIT changed(true);
 }
 
-const KAboutData *KCMApptSummary::aboutData() const
-{
-    auto about = new KAboutData(QStringLiteral("kcmapptsummary"),
-                                i18n("Upcoming Events Configuration Dialog"),
-                                QString(),
-                                QString(),
-                                KAboutLicense::GPL,
-                                i18n("Copyright © 2003–2004 Tobias Koenig\n"
-                                     "Copyright © 2005–2010 Allen Winter"));
-
-    about->addAuthor(i18n("Tobias Koenig"), QString(), QStringLiteral("tokoe@kde.org"));
-    about->addAuthor(i18n("Allen Winter"), QString(), QStringLiteral("winter@kde.org"));
-
-    return about;
-}
 #include "kcmapptsummary.moc"
